/////////////////////////////////////////////////////////////////////////////
// TrayNot.cpp : implementation file
//
// This is a part of the Webster HTTP Server application
// for Microsoft Systems Journal
//
//	Usage: 
//		This class is just a light wrapper around the Windows 95 system
//		tray icon notification facility. The constructor requires a CWnd
//		object pointer in order to deliver the user-defined notification
//		message, which must also be provided. It is up to the caller to 
//		verify that a valid	notification index is provided.
//
//		Typically, the CMainFrame creates this object in the following manner:
//
//		CTrayNot* pTrayObject = new CTrayNot (	this,
//												WM_MY_NOTIFY,
//												"Application stuff");
//
//		When the object is created, it will set the initial icon.
//		Thereafter, the SetIconType() member function is called
//		to select a new icon for the tray.
//
//		The CTrayObject is deleted in the CMainFrame::OnClose handler.
//
/////////////////////////////////////////////////////////////////////////////

#include "stdafx.h"
#include "TrayNot.h"								//Definition for notifications from the tray

#ifdef _DEBUG
#define new DEBUG_NEW
#undef THIS_FILE
static char THIS_FILE[] = __FILE__;
#endif

/////////////////////////////////////////////////////////////////////////////
//	Constructor
//	
CTrayNot::CTrayNot ( CWnd* pWnd, UINT uCallbackMessage, LPCTSTR szTip )
{
	ASSERT( pWnd );
	ASSERT( szTip );
	TRACE( _T("CTrayNot::CTrayNot(%p, %d, %s)\n"), pWnd, uCallbackMessage, szTip );
	// this is only for Windows 95 (or higher)
	m_bEnabled = ( GetVersion() & 0xff ) >= 4 ;
	if ( !m_bEnabled )
		return ;
	//Load the icons
	m_hIconPlain = (HICON)LoadImage( 
			AfxGetInstanceHandle(),
			MAKEINTRESOURCE(IDR_MAINFRAME),
			IMAGE_ICON, 
			16, 16, NULL );
	m_hIconBlink1 = (HICON)LoadImage( 
			AfxGetInstanceHandle(),
			MAKEINTRESOURCE(IDR_MAINFRAME),
			IMAGE_ICON, 
			16, 16, NULL );
	m_hIconBlink2 = (HICON)LoadImage( 
			AfxGetInstanceHandle(),
			MAKEINTRESOURCE(IDR_MAINFRAME),
			IMAGE_ICON, 
			16, 16, NULL );


	// load up the NOTIFYICONDATA structure
	ZeroMemory( &m_tnd, sizeof( m_tnd ) );
	m_tnd.cbSize = sizeof(NOTIFYICONDATA) ;
	m_tnd.hWnd = pWnd->GetSafeHwnd() ;
	m_tnd.uID = 0 ;
	m_tnd.uFlags = NIF_MESSAGE | NIF_ICON | NIF_TIP ;
	m_tnd.uCallbackMessage = uCallbackMessage ;
	strcpy ( m_tnd.szTip, szTip ) ;

	// default icon.
	m_CurType = ePlain;
	m_tnd.hIcon = m_hIconPlain;

	Shell_NotifyIcon ( NIM_ADD, &m_tnd ) ;
}

/////////////////////////////////////////////////////////////////////////////
//	Destructor.
//	Remove icon from tray termination.
//	if this is not done it will linger in the tray until the
//	user moves the mouse over it.
CTrayNot::~CTrayNot()
{
	TRACE( _T("CTrayNot::~CTrayNot()\n") );
	if ( m_bEnabled )
		Shell_NotifyIcon ( NIM_DELETE, &m_tnd ) ;
}


///////////////////////////////////////////////////////////////////////////////
//DESCRIPTION:
//	Change the display of the ICON
//CREATED:
//	18-2-1999  12:49:25
//PARAMS:
//	ture to make the icon Smile
//RETURN:
//	
void CTrayNot::SetIconType( enumIconType eType )
{
	TRACE( _T("CTrayNot::SetIconType( %d )\n"), eType );
	if( m_CurType == eType )
		return;
	switch( eType )
	{
	case ePlain:
		m_tnd.hIcon = m_hIconPlain;
		break;
	case eBlink1:
		m_tnd.hIcon = m_hIconBlink1;
		break;
	case eBlink2:
		m_tnd.hIcon = m_hIconBlink2;
		break;
	default:
		TRACE( _T("OPERATION FAILED : SetIconType( %d )\n"), eType );
	}
	m_CurType = eType;
	Shell_NotifyIcon ( NIM_MODIFY, &m_tnd );
}

 